==> ldap-account-manager_6.2.orig.tar.bz2: ldap-account-manager-6.2/templates/lib/extra/ckeditor/plugins/link/lang/sq.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'sq', {
	acccessKey: 'Sipas ID-së së Elementit',
	advanced: 'Të përparuara',
	advisoryContentType: 'Lloji i Përmbajtjes Këshillimore',
	advisoryTitle: 'Titull',
	anchor: {
		toolbar: 'Spirancë',
		menu: 'Redakto Spirancën',
		title: 'Anchor Properties', // MISSING
		name: 'Emri i Spirancës',
		errorName: 'Ju lutemi shkruani emrin e spirancës',
		remove: 'Largo Spirancën'
	},
	anchorId: 'Sipas ID-së së Elementit',
	anchorName: 'Sipas Emrit të Spirancës',
	charset: 'Seti i Karaktereve të Burimeve të Nëdlidhura',
	cssClasses: 'Klasa stili CSS',
	emailAddress: 'Posta Elektronike',
	emailBody: 'Trupi i Porosisë',
	emailSubject: 'Titulli i Porosisë',
	id: 'Id',
	info: 'Informacione të Nyjes',
	langCode: 'Kod gjuhe',
	langDir: 'Drejtim teksti',
	langDirLTR: 'Nga e majta në të djathë (LTR)',
	langDirRTL: 'Nga e djathta në të majtë (RTL)',
	menu: 'Redakto Nyjen',
	name: 'Emër',
	noAnchors: '(Nuk ka asnjë spirancë në dokument)',
	noEmail: 'Ju lutemi shkruani postën elektronike',
	noUrl: 'Ju lutemi shkruani URL-në e nyjes',
	other: '<tjetër>',
	popupDependent: 'E Varur (Netscape)',
	popupFeatures: 'Karakteristikat e Dritares së Dialogut',
	popupFullScreen: 'Ekran i Plotë  (IE)',
	popupLeft: 'Pozita Majtas',
	popupLocationBar: 'Shiriti i Lokacionit',
	popupMenuBar: 'Shiriti i Menysë',
	popupResizable: 'I ndryshueshëm',
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Shiriti i Statutit',
	popupToolbar: 'Shiriti i Mejteve',
	popupTop: 'Top Pozita',
	rel: 'Marrëdhëniet',
	selectAnchor: 'Përzgjidh një Spirancë',
	styles: 'Stil',
	tabIndex: 'Tab Index', // MISSING
	target: 'Objektivi',
	targetFrame: '<frame>',
	targetFrameName: 'Emri i Kornizës së Synuar',
	targetPopup: '<popup window>',
	targetPopupName: 'Emri i Dritares së Dialogut',
	title: 'Nyja',
	toAnchor: 'Lidhu me spirancën në tekst',
	toEmail: 'Posta Elektronike',
	toUrl: 'URL',
	toolbar: 'Nyja',
	type: 'Lloji i Nyjes',
	unlink: 'Largo Nyjen',
	upload: 'Ngarko'
} );

==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/sq.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'sq', {
	acccessKey: 'Sipas ID-së së Elementit',
	advanced: 'Të përparuara',
	advisoryContentType: 'Lloji i Përmbajtjes Këshillimore',
	advisoryTitle: 'Titull',
	anchor: {
		toolbar: 'Spirancë',
		menu: 'Redakto Spirancën',
		title: 'Anchor Properties', // MISSING
		name: 'Emri i Spirancës',
		errorName: 'Ju lutemi shkruani emrin e spirancës',
		remove: 'Largo Spirancën'
	},
	anchorId: 'Sipas ID-së së Elementit',
	anchorName: 'Sipas Emrit të Spirancës',
	charset: 'Seti i Karaktereve të Burimeve të Nëdlidhura',
	cssClasses: 'Klasa stili CSS',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Posta Elektronike',
	emailBody: 'Trupi i Porosisë',
	emailSubject: 'Titulli i Porosisë',
	id: 'Id',
	info: 'Informacione të Nyjes',
	langCode: 'Kod gjuhe',
	langDir: 'Drejtim teksti',
	langDirLTR: 'Nga e majta në të djathë (LTR)',
	langDirRTL: 'Nga e djathta në të majtë (RTL)',
	menu: 'Redakto Nyjen',
	name: 'Emër',
	noAnchors: '(Nuk ka asnjë spirancë në dokument)',
	noEmail: 'Ju lutemi shkruani postën elektronike',
	noUrl: 'Ju lutemi shkruani URL-në e nyjes',
	other: '<tjetër>',
	popupDependent: 'E Varur (Netscape)',
	popupFeatures: 'Karakteristikat e Dritares së Dialogut',
	popupFullScreen: 'Ekran i Plotë  (IE)',
	popupLeft: 'Pozita Majtas',
	popupLocationBar: 'Shiriti i Lokacionit',
	popupMenuBar: 'Shiriti i Menysë',
	popupResizable: 'I ndryshueshëm',
	popupScrollBars: 'Shiritat zvarritës',
	popupStatusBar: 'Shiriti i Statutit',
	popupToolbar: 'Shiriti i Mejteve',
	popupTop: 'Top Pozita',
	rel: 'Marrëdhëniet',
	selectAnchor: 'Përzgjidh një Spirancë',
	styles: 'Stil',
	tabIndex: 'Indeksi i fletave',
	target: 'Objektivi',
	targetFrame: '<frame>',
	targetFrameName: 'Emri i Kornizës së Synuar',
	targetPopup: '<popup window>',
	targetPopupName: 'Emri i Dritares së Dialogut',
	title: 'Nyja',
	toAnchor: 'Lidhu me spirancën në tekst',
	toEmail: 'Posta Elektronike',
	toUrl: 'URL',
	toolbar: 'Nyja',
	type: 'Lloji i Nyjes',
	unlink: 'Largo Nyjen',
	upload: 'Ngarko'
} );
